diff --git a/.gitlab/issue_templates/Bug.md b/.gitlab/issue_templates/Bug.md
new file mode 100644
index 0000000000000000000000000000000000000000..acdd2ceb295478061c3871e53197038efce41396
--- /dev/null
+++ b/.gitlab/issue_templates/Bug.md
@@ -0,0 +1,23 @@
+# Bug
+## Quick Information
+<!-- This is to help replicate the issue as closely as possible !-->
+- **Kubevirt Chart Version:**
+- **Kubevirt App Version:** 
+- **Other Environment Information:**
+
+## What Happened? / Steps to reproduce
+<!-- A brief description of what happened when you tried to perform an action !-->
+
+## Expected result
+<!-- What should have happened when you performed the actions !-->
+
+## Screenshots / Logs / other relevant information
+<!-- Any relevant data which show the issue !-->
+
+## Priority/Severity
+<!-- The priority and severity assigned may be different to this !-->
+- [ ] High (anything that impacts the normal user flow or blocks app usage)
+- [ ] Medium (anything that negatively affects the user experience)
+- [ ] Low (anything else e.g., typos, missing icons, layout issues, etc.)
+
+/label ~kind::bug ~"Big Bang Third Party" ~triage
\ No newline at end of file
diff --git a/.gitlab/issue_templates/Feature Request.md b/.gitlab/issue_templates/Feature Request.md
new file mode 100644
index 0000000000000000000000000000000000000000..0cbe043d5ab7ccc836cd9cb9e364501ed884468b
--- /dev/null
+++ b/.gitlab/issue_templates/Feature Request.md	
@@ -0,0 +1,14 @@
+# Feature Request
+## Problem Statement
+<!-- What is the issue being faced and needs addressing? !-->
+
+## Benefits and risks
+<!-- What benefits and risks have you considered, if any? !-->
+
+## Proposed solution
+<!-- How would you like to see this issue resolved? !-->
+
+## Examples
+<!-- Are there any examples of this which exist in other software? !-->
+
+/label ~kind::feature ~"Big Bang Third Party" ~triage
\ No newline at end of file
diff --git a/.gitlab/issue_templates/Question.md b/.gitlab/issue_templates/Question.md
new file mode 100644
index 0000000000000000000000000000000000000000..c04784c16f1538f222a287c2cd72fb2c18ec6cba
--- /dev/null
+++ b/.gitlab/issue_templates/Question.md
@@ -0,0 +1,3 @@
+# Question
+
+/label ~question ~"Big Bang Third Party" ~triage
\ No newline at end of file
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 2245e1c273b8a7695a0f51d9b309cd88c32c909b..a55da59c076418f9964bde8f8afbb9a621ecf68f 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -6,6 +6,7 @@ Format: [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
 - Update Kubevirt to v0.53.1
 - Script written with skopeo in order to synchronize images between public locations and repo1
 - Pipeline fixes
+- issue templates, cleanup
 
 ## [0.1.3-alpha-bb.0] - 2022-06-24
 - Initial Chart creation
\ No newline at end of file
diff --git a/Makefile b/Makefile
index 0b0ea51624f48a13d90563e0b669369794c21304..87d33c34c5f9a2e5c0e54d58f5eaec5f6db78497 100644
--- a/Makefile
+++ b/Makefile
@@ -2,7 +2,7 @@ install:
 	helm install kv ./chart --create-namespace --namespace kubevirt
 
 move-images:
-	scripts/move-images.sh
+	utils/registrySync.sh
 
 update-chart:
 	scripts/update-chart.sh
diff --git a/README.md b/README.md
index 7e07e2be566357623f5df5ac844abdedf5e25032..5c3fc79fcfe68575152989c1557620e4a5dc7c94 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
 # kubevirt
 
-![Version: 0.1.3-alpha-bb.4](https://img.shields.io/badge/Version-0.1.3--alpha--bb.4-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: 0.53.1](https://img.shields.io/badge/AppVersion-0.53.1-informational?style=flat-square)
+![Version: 0.1.3-alpha-bb.5](https://img.shields.io/badge/Version-0.1.3--alpha--bb.5-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: 0.53.1](https://img.shields.io/badge/AppVersion-0.53.1-informational?style=flat-square)
 
 KubeVirt Big Bang package
 
@@ -43,4 +43,4 @@ helm install kubevirt chart/
 
 ## Contributing
 
-Please see the [contributing guide](./CONTRIBUTING.md) if you are interested in contributing. 
\ No newline at end of file
+Please see the [contributing guide](./CONTRIBUTING.md) if you are interested in contributing.
diff --git a/chart/Chart.yaml b/chart/Chart.yaml
index c98d062c1a12251129886ca7744684199b35b411..45e6a795dabf3d8a2253de73f8e1af1973c317a3 100644
--- a/chart/Chart.yaml
+++ b/chart/Chart.yaml
@@ -2,5 +2,5 @@ apiVersion: v2
 name: kubevirt
 description: KubeVirt Big Bang package
 type: application
-version: 0.1.3-alpha-bb.4
+version: 0.1.3-alpha-bb.5
 appVersion: "0.53.1"
diff --git a/scripts/move-images.sh b/scripts/move-images.sh
deleted file mode 100755
index 6404437d05c253b295d9c8393020d1b9468e7c75..0000000000000000000000000000000000000000
--- a/scripts/move-images.sh
+++ /dev/null
@@ -1,21 +0,0 @@
-#!/bin/bash
-# Image Info
-export IMGSRC_REPO=quay.io
-export IMGSRC_PROJ=kubevirt
-export IMGDST_REPO=registry.dso.mil
-export IMGDST_PROJ=platform-one/big-bang/apps/third-party/kubevirt
-export IMGTAG=v0.53.1
-
-function pullTagPush() {
-  export IMGNAME=$1
-  docker pull $IMGSRC_REPO/$IMGSRC_PROJ/$IMGNAME:$IMGTAG
-  docker tag $IMGSRC_REPO/$IMGSRC_PROJ/$IMGNAME:$IMGTAG $IMGDST_REPO/$IMGDST_PROJ/$IMGNAME:$IMGTAG
-  docker login $IMGDST_REPO
-  docker push $IMGDST_REPO/$IMGDST_PROJ/$IMGNAME:$IMGTAG
-}
-
-pullTagPush virt-api
-pullTagPush virt-launcher
-pullTagPush virt-handler
-pullTagPush virt-operator
-pullTagPush virt-controller
\ No newline at end of file
diff --git a/scripts/readme-update.sh b/scripts/readme-update.sh
index 4e88184f1c89082cb62939fd5bd84bc7b3adc859..428f50d4814cdf4ad4278d93ea513703ba03961d 100755
--- a/scripts/readme-update.sh
+++ b/scripts/readme-update.sh
@@ -3,11 +3,13 @@
 
 curl -sS -O https://repo1.dso.mil/platform-one/big-bang/apps/library-charts/gluon/-/raw/master/docs/README.md.gotmpl
 curl -sS -O https://repo1.dso.mil/platform-one/big-bang/apps/library-charts/gluon/-/raw/master/docs/.helmdocsignore
+curl -sS -O https://repo1.dso.mil/platform-one/big-bang/apps/library-charts/gluon/-/raw/master/docs/_templates.gotmpl
 
-# Update to your helm-docs binary path
-/usr/local/bin/helm-docs -s file -t `pwd`/README.md.gotmpl --dry-run > README.md
+# Update to your helm-docs binary path (v1.10.0)
+/usr/local/bin/helm-docs -s file -t `pwd`/README.md.gotmpl -t `pwd`/_templates.gotmpl --dry-run > README.md
 # Uncomment to use docker
 # docker run --rm -v "`pwd`:/helm-docs" -u $(id -u) jnorwood/helm-docs:v1.5.0 -s file -t /helm-docs/README.md.gotmpl --dry-run > README.md
 
-rm README.md.gotmpl .helmdocsignore
+rm .helmdocsignore README.md.gotmpl _templates.gotmpl
 git add README.md
+
@@ -3,11 +3,13 @@
 # Uncomment to use docker
-# docker run --rm -v "`pwd`:/helm-docs" -u $(id -u) jnorwood/helm-docs:v1.5.0 -s file -t /helm-docs/README.md.gotmpl --dry-run > README.md
+# docker run --rm -v "`pwd`:/helm-docs" -u $(id -u) jnorwood/helm-docs:v1.10.0 -s file -t /helm-docs/README.md.gotmpl -t /helm-docs/_templates.gotmpl --dry-run > README.md
 